# geodemoch


[![image](https://img.shields.io/pypi/v/geodemoch.svg)](https://pypi.python.org/pypi/geodemoch)


**A test package for iteractive map display**


-   Free software: MIT license
-   Documentation: https://chebil med.github.io/geodemoch
    

## Features

-   TODO

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
